# Period

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**by** | **str** | By is used for legacty, and if exists it will override ByTo and ByFrom | [optional] 
**by_from** | **str** |  | [optional] 
**by_to** | **str** |  | [optional] 
**field** | **str** |  | [optional] 
**from_value** | **str** |  | [optional] 
**to_value** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


